@@ -1,4 +1,4 @@
-binomixp<-function(x,n,alpha0=c(1,1),alpha1=c(1,1),p=0.5,ret=FALSE){
+binomixp = function(x,n,alpha0=c(1,1),alpha1=c(1,1),p=0.5,ret=FALSE){
 
   if(n<x)
     stop("Error: n must be greater than or equal to x")
@@ -12,16 +12,16 @@ binomixp<-function(x,n,alpha0=c(1,1),alpha1=c(1,1),p=0.5,ret=FALSE){
   if(p<=0 || p>=1)
     stop("Error: the mixing proportion p must be in the interval (0,1) exclusive")
 
-  
-  i<-1:x
-  log0<-sum(log(alpha0[1]+i-1)-log(alpha0[1]+alpha0[2]+i-1)+log(n-i+1)-log(i))	
-  log1<-sum(log(alpha1[1]+i-1)-log(alpha1[1]+alpha1[2]+i-1)+log(n-i+1)-log(i))
-  i<-(x+1):n
-  log0<-log0+sum(log(alpha0[2]+i-x-1)-log(alpha0[1]+alpha0[2]+i-1))
-  log1<-log1+sum(log(alpha1[2]+i-x-1)-log(alpha1[1]+alpha1[2]+i-1))
 
-  f0<-exp(log0)
-  f1<-exp(log1)
+  i = 1:x
+  log0 = sum(log(alpha0[1]+i-1)-log(alpha0[1]+alpha0[2]+i-1)+log(n-i+1)-log(i))
+  log1 = sum(log(alpha1[1]+i-1)-log(alpha1[1]+alpha1[2]+i-1)+log(n-i+1)-log(i))
+  i = (x+1):n
+  log0 = log0+sum(log(alpha0[2]+i-x-1)-log(alpha0[1]+alpha0[2]+i-1))
+  log1 = log1+sum(log(alpha1[2]+i-x-1)-log(alpha1[1]+alpha1[2]+i-1))
+
+  f0 = exp(log0)
+  f1 = exp(log1)
 
   cat("Prior probability of the data under component 0\n")
   cat("----------------------------\n")
@@ -32,39 +32,39 @@ binomixp<-function(x,n,alpha0=c(1,1),alpha1=c(1,1),p=0.5,ret=FALSE){
   cat(paste("Log prob.:\t",signif(log1,3),"\nProbability:\t ",signif(f1,5),"\n\n"))
 
 
-  q0<-p
-  q1<-1-q0
-  qp0<-q0*f0/(q0*f0+q1*f1)
-  qp1<-1-qp0
+  q0 = p
+  q1 = 1-q0
+  qp0 = q0*f0/(q0*f0+q1*f1)
+  qp1 = 1-qp0
 
   cat(paste("Post. mixing proportion for component 0:\t",signif(qp0,3),"\n"))
   cat(paste("Post. mixing proportion for component 1:\t",signif(qp1,3),"\n"))
 
-  pi<-seq(0.001,0.999,by=0.001)
+  pi = seq(0.001,0.999,by=0.001)
 
-  prior.0<-dbeta(pi,alpha0[1],alpha0[2])
-  prior.1<-dbeta(pi,alpha1[1],alpha1[2])
-  prior<-q0*prior.0+q1*prior.1
+  prior.0 = dbeta(pi,alpha0[1],alpha0[2])
+  prior.1 = dbeta(pi,alpha1[1],alpha1[2])
+  prior = q0*prior.0+q1*prior.1
 
-  alpha0.post<-alpha0+c(x,n-x)
-  alpha1.post<-alpha1+c(x,n-x)
+  alpha0.post = alpha0+c(x,n-x)
+  alpha1.post = alpha1+c(x,n-x)
 
-  posterior.0<-dbeta(pi,alpha0.post[1],alpha0.post[2])
-  posterior.1<-dbeta(pi,alpha1.post[1],alpha1.post[2])
-  posterior<-qp0*posterior.0+qp1*posterior.1
+  posterior.0 = dbeta(pi,alpha0.post[1],alpha0.post[2])
+  posterior.1 = dbeta(pi,alpha1.post[1],alpha1.post[2])
+  posterior = qp0*posterior.0+qp1*posterior.1
 
-  loglik<-x*log(pi)+(n-x)*log(1-pi)
-  loglik<-loglik-max(loglik)
-  likelihood<-exp(loglik)
+  loglik = x*log(pi)+(n-x)*log(1-pi)
+  loglik = loglik-max(loglik)
+  likelihood = exp(loglik)
 
-  normalizing.factor<-sum(likelihood)/length(likelihood)
-  likelihood<-likelihood/normalizing.factor
+  normalizing.factor = sum(likelihood)/length(likelihood)
+  likelihood = likelihood/normalizing.factor
 
-  o.par<-par(mfrow=c(2,2))
+  o.par = par(mfrow=c(2,2))
 
   ##plot the priors and the mixture prior
 
-  y.max<-max(prior.0,prior.1,prior)
+  y.max = max(prior.0,prior.1,prior)
 
   plot(pi,prior.0,ylim=c(0,y.max*1.1),
        xlab=expression(pi),ylab="Density"
@@ -77,7 +77,7 @@ binomixp<-function(x,n,alpha0=c(1,1),alpha1=c(1,1),p=0.5,ret=FALSE){
 
   ##plot the posteriors and the mixture posterior
 
-  y.max<-max(posterior.0,posterior.1,posterior)
+  y.max = max(posterior.0,posterior.1,posterior)
 
   plot(pi,posterior.0,ylim=c(0,y.max*1.1),
        xlab=expression(pi),ylab="Density"
@@ -90,7 +90,7 @@ binomixp<-function(x,n,alpha0=c(1,1),alpha1=c(1,1),p=0.5,ret=FALSE){
 
   ##plot the mixture posterior likelihood and mixture posterior
 
-  y.max<-max(prior,posterior,likelihood)
+  y.max = max(prior,posterior,likelihood)
 
   plot(pi,prior,ylim=c(0,y.max*1.1),
        xlab=expression(pi),ylab="Density"
@@ -102,12 +102,15 @@ binomixp<-function(x,n,alpha0=c(1,1),alpha1=c(1,1),p=0.5,ret=FALSE){
                    ,expression(posterior[mix])),lty=c(2,3,1),col=c("black","red","green"))
 
   par(o.par)
-  
-  if(ret)
-    return(list(pi=pi,prior=prior,likelihood=likelihood,posterior=posterior))
+
+  if(ret){
+      cat("The argument ret is deprecated.\n")
+      cat("The results are now always returned invisibly\n")
+  }
+  invisible(list(pi=pi,prior=prior,likelihood=likelihood,posterior=posterior))
 }
 
 
 
-	
+
 
